<?php
/**
 * Helper functions
 */

if ( ! function_exists( 'podpro_pingback_header' ) ) :
	/**
	 * Add a pingback url auto-discovery header for singularly identifiable articles.
	 */
	function podpro_pingback_header() {
		if ( is_singular() && pings_open() ) {
			echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
		}
	}

	add_action( 'wp_head', 'podpro_pingback_header' );

endif;

if ( ! function_exists( 'podpro_body_classes' ) ) :
	/**
	 * Adds classes to the body tag
	 */
	function podpro_body_classes( $classes ) {

		// Vars
		$post_layout  = podpro_post_layout();
		$container    = get_theme_mod( 'container_style', 'full-width' );
		$post_style   = get_theme_mod( 'post_style', 'grid' );

		// RTL
		if ( is_rtl() ) {
			$classes[] = 'rtl';
		}

		// Main class
		$classes[] = 'podpro-theme';

		// Container style
		$classes[] = $container . '-container';

		// Sidebar enabled
		if ( 'left-sidebar' == $post_layout
			|| 'right-sidebar' == $post_layout
			&& 'full-width' != $container  ) {
			$classes[] = 'has-sidebar';
		}

		// Content layout
		if ( $post_layout ) {
			$classes[] = $post_layout;
		}

		// Has featured image.
		if ( is_singular() && has_post_thumbnail() ) {
			$classes[] = 'has-featured-image';
		}

		// Content style
		if ( is_home()
			|| is_category()
			|| is_tag()
			|| is_date()
			|| is_author() ) {
			$classes[] = 'post-style-' . $post_style;
		}

		// Return classes
		return $classes;

	}

	add_filter( 'body_class', 'podpro_body_classes' );

endif;

if ( ! function_exists( 'podpro_post_layout' ) ) :
	/**
	 * Returns correct post layout.
	 */
	function podpro_post_layout() {

		// Define variables
		$class  = 'right-sidebar';
		$meta   = get_post_meta( get_the_ID(), 'post_layout', true );

		// Check meta first to override and return (prevents filters from overriding meta)
		if ( is_singular() && $meta ) {
			return $meta;
		}

		// Singular Page
		if ( is_page() ) {

			// Attachment
			if ( is_attachment() && wp_attachment_is_image() ) {
				$class = 'full-width';
			}

			// All other pages
			else {
				$class = get_theme_mod( 'page_layout', 'right-sidebar' );
			}

		}

		// Home
		elseif ( is_home() ) {
			$class = get_theme_mod( 'blog_layout', 'right-sidebar' );
		}

		// Archives
		elseif ( is_category()
			|| is_tag()
			|| is_date()
			|| is_author() ) {
			$class = get_theme_mod( 'archive_layout', 'right-sidebar' );
		}

		// Singular Post
		elseif ( is_singular( 'post' ) ) {
			$class = get_theme_mod( 'post_layout', 'right-sidebar' );
		}

		// Library and Elementor template
		elseif ( is_singular( 'podpro_library' )
    			|| is_singular( 'elementor_library' ) ) {
			$class = 'full-width';
		}

		// Events post type archive page
		elseif ( is_post_type_archive( 'tribe_events' ) ) {
			$class = 'full-width';
		}

		// 404 page
		elseif ( is_404() ) {
			$class = 'full-width-narrow';
		}

		// Podcast archives
		elseif ( is_post_type_archive( 'podcast' ) ) {
			$class = get_theme_mod( 'podcast_layout', 'full-width' );
		}

		// Single podcast
		elseif ( is_singular( 'podcast' ) ) {
			$class = 'full-width';
		}

		// All else
		else {
			$class = 'right-sidebar';
		}

		// Class should never be empty
		if ( empty( $class ) ) {
			$class = 'right-sidebar';
		}

		// Apply filters and return
		return apply_filters( 'podpro_post_layout_class', $class );

	}

endif;

if ( ! function_exists( 'podpro_get_sidebar' ) ) :
	/**
	 * Returns the correct sidebar region.
	 */
	function podpro_get_sidebar( $sidebar = 'primary' ) {

		// Return the correct sidebar name & add useful hook
		$sidebar = apply_filters( 'podpro_get_sidebar', $sidebar );

		// Check meta option after filter so it always overrides
		if ( $meta = get_post_meta( get_the_ID(), 'sidebar', true ) ) {
			$sidebar = $meta;
		}

		// WooCommerce
		if ( podpro_is_woocommerce_activated() ) {
			if ( is_woocommerce() || is_cart() || is_checkout() || is_account_page() ) {
				$sidebar = 'woo_sidebar';
			}
		}

		// Never show empty sidebar
		if ( ! is_active_sidebar( $sidebar ) ) {
			$sidebar = 'primary';
		}

		return $sidebar;
	}
endif;

if ( ! function_exists( 'podpro_header' ) ) {
	/**
	 * Header template
	 */
	function podpro_header() {

		$header = get_theme_mod( 'header_style', 'default' );
		$meta   = get_post_meta( get_the_ID(), 'custom_header_template', true );

		// Check meta option first.
		if ( $meta && is_singular() ) {
			podpro_get_custom_header();
		} elseif ( 'default' != $header ) {
			podpro_get_custom_header();
		} else {
			get_template_part( 'partials/header/header' );
		}

	}

	add_action( 'podpro_header', 'podpro_header' );

}

if ( ! function_exists( 'podpro_get_custom_header' ) ) :
	/**
	 * Get custom header template
	 */
	function podpro_get_custom_header() {

		// Sets up empty variable
		$id = '';

		// Get the template ID
		$id = get_theme_mod( 'header_template', '0' );

		// Get the template ID from metabox
		if ( $meta = get_post_meta( get_the_ID(), 'custom_header_template', true ) ) {
			$id = $meta;
		}

		if ( $id ) {
			$args = array(
				'post_type' => 'podpro_library',
				'p'         => $id
			);
			$loop = new WP_Query ($args );

			while ( $loop->have_posts() ) : $loop->the_post();
				global $post;
				the_content();
			endwhile;

			wp_reset_postdata();
		}

	}

endif;

if ( ! function_exists( 'podpro_footer' ) ) {
	/**
	 * Footer template
	 */
	function podpro_footer() {

		$footer = get_theme_mod( 'footer_style', 'default' );
		$meta   = get_post_meta( get_the_ID(), 'custom_footer_template', true );

		// Check meta option first.
		if ( $meta && is_singular() ) {
			podpro_get_custom_footer();
		} elseif ( 'default' != $footer ) {
			podpro_get_custom_footer();
		} else {
			get_template_part( 'sidebar', 'footer' );
		}

	}

	add_action( 'podpro_footer', 'podpro_footer' );

}

if ( ! function_exists( 'podpro_get_custom_footer' ) ) :
	/**
	 * Get custom footer template
	 */
	function podpro_get_custom_footer(){

		// Sets up empty variable
		$id = '';

		// Get the template ID
		$id = get_theme_mod( 'footer_template', '0' );

		// Get the template ID from metabox
		if ( $meta = get_post_meta( get_the_ID(), 'custom_footer_template', true ) ) {
			$id = $meta;
		}

		if ( $id ){
			$args = array(
				'post_type' => 'podpro_library',
				'p'=> $id
			);
			$loop = new WP_Query ($args );

			while ( $loop->have_posts() ) : $loop->the_post();
				global $post;
				the_content();
			endwhile;

			wp_reset_postdata();
		}

	}

endif;

if ( ! function_exists( 'podpro_archive_header' ) ) :
	/**
	 * Archive header informations.
	 */
	function podpro_archive_header() {
		?>

		<?php if ( is_home() ) : ?>
			<div class="archive-header">
				<div class="archive-content">
					<?php the_archive_title( '<h1 class="archive-title">', '</h1>' ); ?>
				</div>
			</div><!-- .archive-header -->
		<?php endif; ?>

		<?php if ( is_archive() && !is_search() ) : ?>
			<div class="archive-header">
				<div class="archive-content">
					<?php if ( is_author() ) echo get_avatar( get_the_author_meta( 'ID' ) ); ?>
					<?php the_archive_title( '<h1 class="archive-title">', '</h1>' ); ?>
				</div>
			</div><!-- .archive-header -->
		<?php endif; ?>

		<?php if ( is_search() ) : ?>
			<div class="archive-header">
				<div class="archive-content">
					<span class="browse"><?php esc_html_e( 'Search Results for', 'podpro' ); ?></span>
					<h1 class="archive-title"><?php echo get_search_query(); ?></h1>
				</div>
			</div><!-- .archive-header -->
		<?php endif; ?>

		<?php if ( is_singular( 'page' ) && !is_page_template() ) : ?>
			<div class="archive-header">
				<div class="archive-content">
					<?php the_title( '<h1 class="page-title">', '</h1>' ); ?>
				</div>
			</div><!-- .archive-header -->
		<?php endif; ?>

	<?php
	}

	add_action( 'podpro_header', 'podpro_archive_header', 10 );

endif;

if ( ! function_exists( 'podpro_post_classes' ) ) :
	/**
	 * Adds custom classes to the array of post classes.
	 */
	function podpro_post_classes( $classes ) {

		// Replace hentry class with entry.
		$classes[] = 'entry';

		return $classes;
	}

	add_filter( 'post_class', 'podpro_post_classes' );

endif;

if ( ! function_exists( 'podpro_remove_hentry' ) ) :
	/**
	 * Remove 'hentry' from post_class()
	 */
	function podpro_remove_hentry( $class ) {
		$class = array_diff( $class, array( 'hentry' ) );
		return $class;
	}

	add_filter( 'post_class', 'podpro_remove_hentry' );

endif;

if ( ! function_exists( 'podpro_excerpt_more' ) ) :
	/**
	 * Change the excerpt more string.
	 */
	function podpro_excerpt_more( $more ) {
		return '&hellip;';
	}

	add_filter( 'excerpt_more', 'podpro_excerpt_more' );

endif;

if ( ! function_exists( 'podpro_custom_excerpt_length' ) ) :
	/**
	 * Filter the excerpt length.
	 */
	function podpro_custom_excerpt_length( $length ) {

		// Sets default
		$length = 20;

		// Get the user settings
		$setting = get_theme_mod( 'excerpt', 20 );
		if ( 20 != $setting ) {
			$length = $setting;
		}

		return $length;
	}

	add_filter( 'excerpt_length', 'podpro_custom_excerpt_length', 999 );

endif;

if ( ! function_exists( 'podpro_extend_archive_title' ) ) :
	/**
	 * Extend archive title
	 */
	function podpro_extend_archive_title( $title ) {
		if ( is_post_type_archive( 'product' ) ) {
			$default = get_theme_mod( 'shop_title', esc_attr__( 'Products', 'podpro' ) );
			$title = $default;
		} elseif ( is_post_type_archive( 'portfolio' ) ) {
			$title = esc_attr__( 'Portfolio', 'podpro' );
		} elseif ( is_post_type_archive( 'tribe_events' ) ) {
			$title = esc_attr__( 'Events', 'podpro' );
		} elseif ( is_post_type_archive( 'podcast' ) ) {
			$title = esc_attr__( 'All Episodes', 'podpro' );
		} elseif ( is_tax() ) {
			$title = single_term_title( '', false );
		} elseif ( is_home() ) {
			$title = esc_html__( 'Blog', 'podpro' );
		}
		return $title;
	}

	add_filter( 'get_the_archive_title', 'podpro_extend_archive_title' );

endif;

if ( ! function_exists( 'podpro_customize_tag_cloud' ) ) :
	/**
	 * Customize tag cloud widget
	 */
	function podpro_customize_tag_cloud( $args ) {
		$args['largest']  = 13;
		$args['smallest'] = 13;
		$args['unit']     = 'px';
		$args['number']   = 20;
		return $args;
	}

	add_filter( 'widget_tag_cloud_args', 'podpro_customize_tag_cloud' );

endif;

/**
 * Add a dropdown icon to top-level menu items.
 */
function instock_add_dropdown_icons( $output, $item, $depth, $args ) {

	// Only add class to 'top level' items on the 'primary' menu.
	if ( 'mobile' !== $args->theme_location ) {
		return $output;
	}

	if ( in_array( 'menu-item-has-children', $item->classes, true ) ) {

		// Add SVG icon to parent items.
		$icon = '<i class="icon-arrow-down"></i>';

		$output .= sprintf(
			'<button class="submenu-expand" tabindex="-1">%s</button>',
			$icon
		);
	}

	return $output;
}
add_filter( 'walker_nav_menu_start_el', 'instock_add_dropdown_icons', 10, 4 );
